@@ -15,11 +15,11 @@ class RcsMessage:
             scheme.RcsLMSBody,
             scheme.RcsMMSBody,
             scheme.RcsCHATBody,
-            # scheme.RcsTMPLBody,
             scheme.RcsSMSCarouselBody,
             scheme.RcsLMSCarouselBody,
             scheme.RcsMMSCarouselBody,
             scheme.RcsCHATCarouselBody,
+            dict,
         ],
         agency_id: Optional[str] = None,
         message_base_id: Union[enums.MessageEnum, enums.RCSMessageEnum] = enums.MessageEnum.SMS,
@@ -69,7 +69,7 @@ class RcsMessage:
             rcs_info.agencyId = self.agency_id
         if self.expiry_option:
             rcs_info.expiryOption = self.expiry_option
-        elif self.service_type == enums.ServiceTypeEnum.CHAT:
+        if self.service_type == enums.ServiceTypeEnum.CHAT:
             rcs_info.expiryOption = enums.ExpiryOptionEnum.AFTER_SETTING_TIMES
         if self.footer:
             rcs_info.footer = self.footer
