@@ -3,7 +3,7 @@ from typing import Dict, List, Optional, Union
 from pydantic import BaseModel, Field, validator
 
 from . import enums
-from .errors import ErrorCodeEnum, LegacyErrorCodeEnum
+from .errors import LegacyErrorCodeEnum
 
 
 class EmptyDict:
@@ -128,11 +128,6 @@ class RcsCHATCarouselBody(BaseModel):
     media6: Optional[str]
 
 
-class RcsTMPLBody(BaseModel):
-    # TODO
-    pass
-
-
 class LocationInfo(BaseModel):
     query: Optional[str]
     longitude: Optional[float]
@@ -293,7 +288,7 @@ class RcsInfo(BaseModel):
     * Agency ID는 "Rcs Biz Center - 브랜드 운영관리" 에서 기업의 브랜드가 대행사 권한을 부여한 대행사의 ID
     Agency ID가 "ktbizrcs" 가 아닌 경우 필수 입력 필요.
     """
-    messagebaseId: Union[enums.MessageEnum, enums.RCSMessageEnum]
+    messagebaseId: Union[enums.MessageEnum, enums.RCSMessageEnum, str]
     serviceType: enums.ServiceTypeEnum
     expiryOption: Optional[enums.ExpiryOptionEnum]
     """
@@ -347,11 +342,11 @@ class RcsInfo(BaseModel):
         RcsLMSBody,
         RcsMMSBody,
         RcsCHATBody,
-        # RcsTMPLBody,
         RcsSMSCarouselBody,
         RcsLMSCarouselBody,
         RcsMMSCarouselBody,
         RcsCHATCarouselBody,
+        dict,
     ]
     """
     # body
@@ -389,7 +384,7 @@ class RcsInfo(BaseModel):
     버튼의 변수부를 등록 하여 사용하며, 해당 필드 허용하지 않음.
     """
 
-    chipList: Optional[List]
+    chipList: Optional[List[SuggestionInfo]]
     """
     # chipList
     GSMA RCC.07의3.6.10.4의 ‘suggestion’ 규격에 따라 chiplist를 구성(RCC.07의 기준 버전 확인 필요)
@@ -406,6 +401,9 @@ class RcsInfo(BaseModel):
     *양방향서비스에서 양방향 대화의 세션을 관리하는 기준으로, 고객이 양방향 MO를 수행할 때마다 새롭게 할당되며, 유효시간은 24시간임. 유효시간이 만료된 replyId포함되어 발송되면 실패처리된다
     """
 
+    class Config:
+        smart_union = True
+
 
 class LegacyInfo(BaseModel):
     """
@@ -447,6 +445,16 @@ class LegacyInfo(BaseModel):
     """
 
 
+class ErrorInfo(BaseModel):
+    code: str
+    message: str
+
+
+class ResponseErrorInfo(BaseModel):
+    status: str
+    error: ErrorInfo
+
+
 class StatusInfo(BaseModel):
     """
     메시지 전송 결과
@@ -459,7 +467,7 @@ class StatusInfo(BaseModel):
     serviceType: Optional[enums.ServiceTypeEnum]
     mnoInfo: Optional[enums.MnoInfoEnum]
     sentTime: Optional[str] = Field(regex=r"^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{3}\+\d{2}$")
-    error: Optional[ErrorCodeEnum]
+    error: Optional[ErrorInfo]
     legacyError: Optional[LegacyErrorCodeEnum]
     timestamp: str = Field(regex=r"^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{3}\+\d{2}$")
     autoReplyMsgId: Optional[str] = Field(max_length=40)
@@ -473,16 +481,6 @@ class QuerystatusInfo(BaseModel):
     moreToSend: Optional[int] = Field(ge=0, le=1)
 
 
-class ErrorInfo(BaseModel):
-    code: str
-    message: str
-
-
-class ResponseErrorInfo(BaseModel):
-    status: str
-    error: ErrorInfo
-
-
 class ResponseInfo(BaseModel):
     status: str
     data: dict
